pub struct ChatbotError {
error_type: <ChatbotError as BackendError>::ErrorType,
message: String,
source: Option<Error>,
span_trace: Box<SpanTrace>,
backtrace: Box<Backtrace>,
location: Option<&'static Location<'static>>,
azure_source: Option<Box<ResponseError>>,
}Expand description
Error type used in ChatbotError, which is used for errors related to chatbot functionality.
All the information in the error is meant to be seen by the user. The type of error is determined by the ChatbotErrorType enum, which is stored inside this struct.
Examples
Usage without source error
if erroneous_condition {
return Err(ChatbotError::new(
ChatbotErrorType::Other,
"File not found".to_string(),
None,
));
}Usage with a source error
Used when calling a function that returns an error that cannot be automatically converted to an ChatbotError. (See impl From<X> implementations on this struct.)
some_function_returning_an_error().map_err(|original_error| {
ChatbotError::new(
ChatbotErrorType::Other,
"Library x failed to do y".to_string(),
Some(original_error.into()),
)
})?;Fields
error_type: <ChatbotError as BackendError>::ErrorTypemessage: Stringsource: Option<Error>Original error that caused this error.
span_trace: Box<SpanTrace>A trace of tokio tracing spans, generated automatically when the error is generated.
backtrace: Box<Backtrace>Stack trace, generated automatically when the error is created.
location: Option<&'static Location<'static>>Source location where the error was raised.
azure_source: Option<Box<ResponseError>>Implementations
Sourceimpl ChatbotError
impl ChatbotError
fn render_clean_error(&self, out: &mut dyn Write, color: ColorChoice) -> Result
Sourcepub fn clean_string(&self, color: ColorChoice) -> String
pub fn clean_string(&self, color: ColorChoice) -> String
Render this error in the clean developer format.
Sourceimpl ChatbotError
impl ChatbotError
pub fn azure_source(&self) -> Option<AzureResponseError>
pub fn add_azure_source(&mut self, err: AzureResponseError)